@@ -10,7 +10,7 @@ use warnings;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2022-02-05'; # DATE
 our $DIST = 'Begin-Eval-Env'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 my @envs;
 sub import {
@@ -40,7 +40,7 @@ Begin::Eval::Env - Take code from environment variable(s), then eval them
 
 =head1 VERSION
 
-This document describes version 0.002 of Begin::Eval::Env (from Perl distribution Begin-Eval-Env), released on 2022-02-05.
+This document describes version 0.003 of Begin::Eval::Env (from Perl distribution Begin-Eval-Env), released on 2022-02-05.
 
 =head1 SYNOPSIS
 
@@ -60,6 +60,9 @@ This module allows you to evaluate code(s) in environment variable(s), basically
 for convenience in one-liners. If name(s) of environment variables are not
 specified, C<PERL_BEGIN_EVAL_ENV> is the default.
 
+Caveat: to run the code(s) in BEGIN block, you have to load the module in the
+BEGIN block also, e.g. via "use" not "require".
+
 The purpose of Begin::Eval::* and End::Eval::* modules is to allow you to
 evaluate some extra Perl code in addition to running your application,
 respectively at the beginning and at the end. The code can be supplied via one
